AbsoluteOrientationEvent class

Constructors

AbsoluteOrientationEvent([double yaw = 0, double pitch = 0, double roll = 0, double x = 0, double y = 0, double z = 0, double w = 0])
AbsoluteOrientationEvent.fromList(List<double> list)

Properties

eulerAngles → List<double>
no setter
hashCode → int
The hash code for this object.
no setterinherited
pitch → double
The pitch of the device in radians.
final
quaternion → List<double>
no setter
roll → double
The roll of the device in radians.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeStamp ↔ int
latefinal
timeStampNS ↔ int
latefinal
w → double
final
x → double
final
y → double
final
yaw → double
The yaw of the device in radians.
final
z → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
quantFromAxis(QuaternionOrientation orientation, [List<double>? multiply]) → List<double>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited