GyroscopeEvent class

Discrete reading from a gyroscope. Gyroscopes measure the rate or rotation of the device in 3D space.

Constructors

GyroscopeEvent(double x, double y, double z)
Contructs an instance with the given x, y, and z values.
GyroscopeEvent.fromList(List<double> list)

Properties

data ↔ List<double>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeStamp ↔ int
latefinal
timeStampNS ↔ int
latefinal
x → double
Rate of rotation around the x axis measured in rad/s.
final
y → double
Rate of rotation around the y axis measured in rad/s.
final
z → double
Rate of rotation around the z axis measured in rad/s.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited